==> chartjs-2.0.1-0.jar: cljsjs/chartjs/common/chartjs.ext.js <==
var Chart = {
  "defaults": {},
  "helpers": {},
  "elements": {},
  "Element": {
    "extend": function () {}
  },
  "Animation": {
    "extend": function () {},
    "__super__": {}
  },
  "animationService": {},
  "types": {},
  "instances": {},
  "controllers": {},
  "Controller": function () {},
  "DatasetController": {
    "extend": function () {}
  },
  "layoutService": {},
  "Legend": {
    "extend": function () {},
    "__super__": {}
  },
  "Scale": {
    "extend": function () {},
    "__super__": {}
  },
  "scaleService": {},
  "Title": {
    "extend": function () {},
    "__super__": {}
  },
  "Tooltip": {
    "extend": function () {},
    "__super__": {}
  },
  "Bar": function () {},
  "Bubble": function () {},
  "Doughnut": function () {},
  "Line": function () {},
  "PolarArea": function () {},
  "Radar": function () {},
  "Scatter": function () {}
};
Chart.Element.prototype = {
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Animation.prototype = {
  "constructor": function () {},
  "currentStep": function () {},
  "numSteps": function () {},
  "easing": function () {},
  "render": function () {},
  "onAnimationProgress": function () {},
  "onAnimationComplete": function () {},
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Controller.prototype = {
  "initialize": function () {},
  "clear": function () {},
  "stop": function () {},
  "resize": function () {},
  "ensureScalesHaveIDs": function () {},
  "buildScales": function () {},
  "buildSurroundingItems": function () {},
  "updateLayout": function () {},
  "buildOrUpdateControllers": function () {},
  "resetElements": function () {},
  "update": function () {},
  "render": function () {},
  "draw": function () {},
  "getElementAtEvent": function () {},
  "getElementsAtEvent": function () {},
  "getDatasetAtEvent": function () {},
  "generateLegend": function () {},
  "destroy": function () {},
  "toBase64Image": function () {},
  "initToolTip": function () {},
  "bindEvents": function () {},
  "eventHandler": function () {}
};
Chart.DatasetController.prototype = {
  "initialize": function () {},
  "updateIndex": function () {},
  "linkScales": function () {},
  "getDataset": function () {},
  "getScaleForId": function () {},
  "reset": function () {},
  "buildOrUpdateElements": function () {},
  "addElements": function () {},
  "addElementAndReset": function () {},
  "draw": function () {},
  "removeHoverStyle": function () {},
  "setHoverStyle": function () {},
  "update": function () {}
};
Chart.Legend.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeBuildLabels": function () {},
  "buildLabels": function () {},
  "afterBuildLabels": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "draw": function () {},
  "handleEvent": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Scale.prototype = {
  "constructor": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeDataLimits": function () {},
  "determineDataLimits": function () {},
  "afterDataLimits": function () {},
  "beforeBuildTicks": function () {},
  "buildTicks": function () {},
  "afterBuildTicks": function () {},
  "beforeTickToLabelConversion": function () {},
  "convertTicksToLabels": function () {},
  "afterTickToLabelConversion": function () {},
  "beforeCalculateTickRotation": function () {},
  "calculateTickRotation": function () {},
  "afterCalculateTickRotation": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "isFullWidth": function () {},
  "getRightValue": function () {},
  "getLabelForIndex": function () {},
  "getPixelForValue": function () {},
  "getPixelForTick": function () {},
  "getPixelForDecimal": function () {},
  "draw": function () {},
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Title.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeBuildLabels": function () {},
  "buildLabels": function () {},
  "afterBuildLabels": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "draw": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Tooltip.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "getTitle": function () {},
  "getBeforeBody": function () {},
  "getBody": function () {},
  "getAfterBody": function () {},
  "getFooter": function () {},
  "getAveragePosition": function () {},
  "update": function () {},
  "getTooltipSize": function () {},
  "determineAlignment": function () {},
  "getBackgroundPoint": function () {},
  "drawCaret": function () {},
  "drawTitle": function () {},
  "drawBody": function () {},
  "drawFooter": function () {},
  "draw": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
var Color = {};
Color.prototype = {
  "rgb": function () {},
  "hsl": function () {},
  "hsv": function () {},
  "hwb": function () {},
  "cmyk": function () {},
  "rgbArray": function () {},
  "hslArray": function () {},
  "hsvArray": function () {},
  "hwbArray": function () {},
  "cmykArray": function () {},
  "rgbaArray": function () {},
  "hslaArray": function () {},
  "alpha": function () {},
  "red": function () {},
  "green": function () {},
  "blue": function () {},
  "hue": function () {},
  "saturation": function () {},
  "lightness": function () {},
  "saturationv": function () {},
  "whiteness": function () {},
  "blackness": function () {},
  "value": function () {},
  "cyan": function () {},
  "magenta": function () {},
  "yellow": function () {},
  "black": function () {},
  "hexString": function () {},
  "rgbString": function () {},
  "rgbaString": function () {},
  "percentString": function () {},
  "hslString": function () {},
  "hslaString": function () {},
  "hwbString": function () {},
  "keyword": function () {},
  "rgbNumber": function () {},
  "luminosity": function () {},
  "contrast": function () {},
  "level": function () {},
  "dark": function () {},
  "light": function () {},
  "negate": function () {},
  "lighten": function () {},
  "darken": function () {},
  "saturate": function () {},
  "desaturate": function () {},
  "whiten": function () {},
  "blacken": function () {},
  "greyscale": function () {},
  "clearer": function () {},
  "opaquer": function () {},
  "rotate": function () {},
  "mix": function () {},
  "toJSON": function () {},
  "clone": function () {},
  "getValues": function () {},
  "setValues": function () {},
  "setSpace": function () {},
  "setChannel": function () {}
};

==> chartjs-2.3.0-0.jar: cljsjs/chartjs/common/chartjs.ext.js <==
var Chart = {
  "defaults": {},
  "helpers": {},
  "canvasHelpers": {},
  "elements": {},
  "Element": {
    "extend": function () {}
  },
  "Animation": {
    "extend": function () {},
    "__super__": {}
  },
  "animationService": {},
  "types": {},
  "instances": {},
  "controllers": {},
  "Controller": function () {},
  "DatasetController": {
    "extend": function () {}
  },
  "layoutService": {},
  "Legend": {
    "extend": function () {},
    "__super__": {}
  },
  "Scale": {
    "extend": function () {},
    "__super__": {}
  },
  "scaleService": {},
  "plugins": {},
  "pluginBase": function () {},
  "pluginService": {},
  "Title": {
    "extend": function () {},
    "__super__": {}
  },
  "Tooltip": {
    "extend": function () {},
    "__super__": {}
  },
  "LinearScaleBase": function () {},
  "Bar": function () {},
  "Bubble": function () {},
  "Doughnut": function () {},
  "Line": function () {},
  "PolarArea": function () {},
  "Radar": function () {},
  "Scatter": function () {}
};
Chart.Element.prototype = {
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Animation.prototype = {
  "constructor": function () {},
  "currentStep": function () {},
  "numSteps": function () {},
  "easing": function () {},
  "render": function () {},
  "onAnimationProgress": function () {},
  "onAnimationComplete": function () {},
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Controller.prototype = {
  "initialize": function () {},
  "clear": function () {},
  "stop": function () {},
  "resize": function () {},
  "ensureScalesHaveIDs": function () {},
  "buildScales": function () {},
  "buildSurroundingItems": function () {},
  "updateLayout": function () {},
  "buildOrUpdateControllers": function () {},
  "resetElements": function () {},
  "update": function () {},
  "render": function () {},
  "draw": function () {},
  "getElementAtEvent": function () {},
  "getElementsAtEvent": function () {},
  "getDatasetAtEvent": function () {},
  "generateLegend": function () {},
  "destroy": function () {},
  "toBase64Image": function () {},
  "initToolTip": function () {},
  "bindEvents": function () {},
  "eventHandler": function () {}
};
Chart.DatasetController.prototype = {
  "initialize": function () {},
  "updateIndex": function () {},
  "linkScales": function () {},
  "getDataset": function () {},
  "getScaleForId": function () {},
  "reset": function () {},
  "buildOrUpdateElements": function () {},
  "addElements": function () {},
  "addElementAndReset": function () {},
  "draw": function () {},
  "removeHoverStyle": function () {},
  "setHoverStyle": function () {},
  "update": function () {}
};
Chart.Legend.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeBuildLabels": function () {},
  "buildLabels": function () {},
  "afterBuildLabels": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "draw": function () {},
  "handleEvent": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Scale.prototype = {
  "constructor": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeDataLimits": function () {},
  "determineDataLimits": function () {},
  "afterDataLimits": function () {},
  "beforeBuildTicks": function () {},
  "buildTicks": function () {},
  "afterBuildTicks": function () {},
  "beforeTickToLabelConversion": function () {},
  "convertTicksToLabels": function () {},
  "afterTickToLabelConversion": function () {},
  "beforeCalculateTickRotation": function () {},
  "calculateTickRotation": function () {},
  "afterCalculateTickRotation": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "isFullWidth": function () {},
  "getRightValue": function () {},
  "getLabelForIndex": function () {},
  "getPixelForValue": function () {},
  "getPixelForTick": function () {},
  "getPixelForDecimal": function () {},
  "draw": function () {},
  "initialize": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Title.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "beforeUpdate": function () {},
  "update": function () {},
  "afterUpdate": function () {},
  "beforeSetDimensions": function () {},
  "setDimensions": function () {},
  "afterSetDimensions": function () {},
  "beforeBuildLabels": function () {},
  "buildLabels": function () {},
  "afterBuildLabels": function () {},
  "beforeFit": function () {},
  "fit": function () {},
  "afterFit": function () {},
  "isHorizontal": function () {},
  "draw": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
Chart.Tooltip.prototype = {
  "constructor": function () {},
  "initialize": function () {},
  "getTitle": function () {},
  "getBeforeBody": function () {},
  "getBody": function () {},
  "getAfterBody": function () {},
  "getFooter": function () {},
  "getAveragePosition": function () {},
  "update": function () {},
  "getTooltipSize": function () {},
  "determineAlignment": function () {},
  "getBackgroundPoint": function () {},
  "drawCaret": function () {},
  "drawTitle": function () {},
  "drawBody": function () {},
  "drawFooter": function () {},
  "draw": function () {},
  "pivot": function () {},
  "transition": function () {},
  "tooltipPosition": function () {},
  "hasValue": function () {}
};
var Color = {};
Color.prototype = {
  "rgb": function () {},
  "hsl": function () {},
  "hsv": function () {},
  "hwb": function () {},
  "cmyk": function () {},
  "rgbArray": function () {},
  "hslArray": function () {},
  "hsvArray": function () {},
  "hwbArray": function () {},
  "cmykArray": function () {},
  "rgbaArray": function () {},
  "hslaArray": function () {},
  "alpha": function () {},
  "red": function () {},
  "green": function () {},
  "blue": function () {},
  "hue": function () {},
  "saturation": function () {},
  "lightness": function () {},
  "saturationv": function () {},
  "whiteness": function () {},
  "blackness": function () {},
  "value": function () {},
  "cyan": function () {},
  "magenta": function () {},
  "yellow": function () {},
  "black": function () {},
  "hexString": function () {},
  "rgbString": function () {},
  "rgbaString": function () {},
  "percentString": function () {},
  "hslString": function () {},
  "hslaString": function () {},
  "hwbString": function () {},
  "keyword": function () {},
  "rgbNumber": function () {},
  "luminosity": function () {},
  "contrast": function () {},
  "level": function () {},
  "dark": function () {},
  "light": function () {},
  "negate": function () {},
  "lighten": function () {},
  "darken": function () {},
  "saturate": function () {},
  "desaturate": function () {},
  "whiten": function () {},
  "blacken": function () {},
  "greyscale": function () {},
  "clearer": function () {},
  "opaquer": function () {},
  "rotate": function () {},
  "mix": function () {},
  "toJSON": function () {},
  "clone": function () {},
  "getValues": function () {},
  "setValues": function () {},
  "setSpace": function () {},
  "setChannel": function () {}
};
